==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/Schemas/SearchSchemas.pm <==

package Paws::Schemas::SearchSchemas;
  use Moose;
  has Keywords => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'keywords', required => 1);
  has Limit => (is => 'ro', isa => 'Int', traits => ['ParamInQuery'], query_name => 'limit');
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'nextToken');
  has RegistryName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'registryName', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SearchSchemas');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/v1/registries/name/{registryName}/schemas/search');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Schemas::SearchSchemasResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Schemas::SearchSchemas - Arguments for method SearchSchemas on L<Paws::Schemas>

=head1 DESCRIPTION

This class represents the parameters used for calling the method SearchSchemas on the
L<Schemas|Paws::Schemas> service. Use the attributes of this class
as arguments to method SearchSchemas.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to SearchSchemas.

=head1 SYNOPSIS

    my $schemas = Paws->service('Schemas');
    my $SearchSchemasResponse = $schemas->SearchSchemas(
      Keywords     => 'My__string',
      RegistryName => 'My__string',
      Limit        => 1,               # OPTIONAL
      NextToken    => 'My__string',    # OPTIONAL
    );

    # Results:
    my $NextToken = $SearchSchemasResponse->NextToken;
    my $Schemas   = $SearchSchemasResponse->Schemas;

    # Returns a L<Paws::Schemas::SearchSchemasResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/schemas/SearchSchemas>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Keywords => Str





=head2 Limit => Int





=head2 NextToken => Str





=head2 B<REQUIRED> RegistryName => Str






=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SearchSchemas in L<Paws::Schemas>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/Schemas/SearchSchemas.pm <==

package Paws::Schemas::SearchSchemas;
  use Moose;
  has Keywords => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'keywords', required => 1);
  has Limit => (is => 'ro', isa => 'Int', traits => ['ParamInQuery'], query_name => 'limit');
  has NextToken => (is => 'ro', isa => 'Str', traits => ['ParamInQuery'], query_name => 'nextToken');
  has RegistryName => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'registryName', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'SearchSchemas');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/v1/registries/name/{registryName}/schemas/search');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Schemas::SearchSchemasResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Schemas::SearchSchemas - Arguments for method SearchSchemas on L<Paws::Schemas>

=head1 DESCRIPTION

This class represents the parameters used for calling the method SearchSchemas on the
L<Schemas|Paws::Schemas> service. Use the attributes of this class
as arguments to method SearchSchemas.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to SearchSchemas.

=head1 SYNOPSIS

    my $schemas = Paws->service('Schemas');
    my $SearchSchemasResponse = $schemas->SearchSchemas(
      Keywords     => 'My__string',
      RegistryName => 'My__string',
      Limit        => 1,               # OPTIONAL
      NextToken    => 'My__string',    # OPTIONAL
    );

    # Results:
    my $NextToken = $SearchSchemasResponse->NextToken;
    my $Schemas   = $SearchSchemasResponse->Schemas;

    # Returns a L<Paws::Schemas::SearchSchemasResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/schemas/SearchSchemas>

=head1 ATTRIBUTES


=head2 B<REQUIRED> Keywords => Str

Specifying this limits the results to only schemas that include the
provided keywords.



=head2 Limit => Int





=head2 NextToken => Str

The token that specifies the next page of results to return. To request
the first page, leave NextToken empty. The token will expire in 24
hours, and cannot be shared with other accounts.



=head2 B<REQUIRED> RegistryName => Str

The name of the registry.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method SearchSchemas in L<Paws::Schemas>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
